Module dioxus_core::nodes [−][src]
Virtual Node Support VNodes represent lazily-constructed VDom trees that support diffing and event handlers.
These VNodes should be very cheap and very fast to construct - building a full tree should be insanely quick.
Structs
| Attribute | An attribute on a DOM node, such as |
| DomTree | A domtree represents the result of “Viewing” the context It’s a placeholder over vnodes, to make working with lifetimes easier |
| Listener | An event listener. |
| NodeKey | The key for keyed children. |
| VComponent | |
| VElement | |
| VText |
Enums
| VNode |