Attribute Macro dioxus_core::prelude::fc [−][src]
#[fc]
Label a function or static closure as a functional component. This macro reduces the need to create a separate properties struct.
#[fc]
Label a function or static closure as a functional component. This macro reduces the need to create a separate properties struct.