Function dioxus_core::prelude::queue_effect
source · pub fn queue_effect(f: impl FnOnce() + 'static)Expand description
Queue an effect to run after the next render
pub fn queue_effect(f: impl FnOnce() + 'static)Queue an effect to run after the next render