pub struct Template { /* private fields */ }Expand description
A static layout of a UI tree that describes a set of dynamic and static nodes.
This is the core innovation in Dioxus. Most UIs are made of static nodes, yet participate in diffing like any dynamic node. This struct can be created at compile time. It promises that its pointer is unique, allow Dioxus to use its static description of the UI to skip immediately to the dynamic nodes during diffing.
Implementations
Sourceimpl Template
impl Template
Sourcepub const fn new(
roots: &'static [TemplateNode],
node_paths: &'static [&'static [u8]],
attr_paths: &'static [&'static [u8]],
) -> Self
pub const fn new( roots: &'static [TemplateNode], node_paths: &'static [&'static [u8]], attr_paths: &'static [&'static [u8]], ) -> Self
Create a new Template with the given roots, node_paths, and attr_paths. The hash is computed automatically from the template content.
Sourcepub const fn roots(&self) -> &'static [TemplateNode]
pub const fn roots(&self) -> &'static [TemplateNode]
Get the template nodes that make up this template.
Sourcepub const fn node_paths(&self) -> &'static [&'static [u8]]
pub const fn node_paths(&self) -> &'static [&'static [u8]]
Get the paths of each dynamic node relative to the root of the template.
Sourcepub const fn attr_paths(&self) -> &'static [&'static [u8]]
pub const fn attr_paths(&self) -> &'static [&'static [u8]]
Get the paths of each dynamic attribute relative to the root of the template.