Module dioxus_core::virtual_dom[][src]

Structs

LifecycleEvent
VirtualDom

An integrated virtual node system that progresses events and diffs UI trees. Differences are converted into patches which a renderer can use to draw the UI.

Enums

LifecycleType