Enum dioxus_core::nodes::VNode [−][src]
Variants
Element(&'src VElement<'src>)An element node (node type ELEMENT_NODE).
Text(VText<'src>)A text node (node type TEXT_NODE).
Note: This wraps a VText instead of a plain String in
order to enable custom methods like create_text_node() on the
wrapped type.
A “suspended component” This is a masqeurade over an underlying future that needs to complete When the future is completed, the VNode will then trigger a render
Component(VComponent<'src>)A User-defined componen node (node type COMPONENT_NODE)
Implementations
impl<'a> VNode<'a>[src]
pub fn element(
bump: &'a Bump,
key: NodeKey,
tag_name: &'a str,
listeners: &'a [Listener<'a>],
attributes: &'a [Attribute<'a>],
children: &'a [VNode<'a>],
namespace: Option<&'a str>
) -> VNode<'a>[src]
bump: &'a Bump,
key: NodeKey,
tag_name: &'a str,
listeners: &'a [Listener<'a>],
attributes: &'a [Attribute<'a>],
children: &'a [VNode<'a>],
namespace: Option<&'a str>
) -> VNode<'a>
Low-level constructor for making a new Node of type element with given
parts.
This is primarily intended for JSX and templating proc-macros to compile
down into. If you are building nodes by-hand, prefer using the
dodrio::builder::* APIs.
pub fn text(text: &'a str) -> VNode<'a>[src]
Construct a new text node with the given text.